@@ -20,4 +20,8 @@ from .elastic_server import QElasticServer
 from .vnc_server import QVNCServer
 from .qbsniffer import QBSniffer
 from .ldap_server import QLDAPServer
+from .ntp_server import QNTPServer
+from .memcache_server import QMemcacheServer
+from .oracle_server import QOracleServer
+from .snmp_server import QSNMPServer
 from .helper import server_arguments, clean_all, kill_servers, get_free_port, close_port_wrapper, kill_server_wrapper, setup_logger, disable_logger, postgres_class, get_running_servers, set_local_vars
