@@ -4,7 +4,7 @@ from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
 filterwarnings('ignore', category=RuntimeWarning, module='runpy')
 
-all_servers = ['QDNSServer', 'QFTPServer', 'QHTTPProxyServer', 'QHTTPServer', 'QHTTPSServer', 'QIMAPServer', 'QMysqlServer', 'QPOP3Server', 'QPostgresServer', 'QRedisServer', 'QSMBServer', 'QSMTPServer', 'QSOCKS5Server', 'QSSHServer', 'QTelnetServer', 'QVNCServer', 'QElasticServer', 'QMSSQLServer', 'QLDAPServer']
+all_servers = ['QDNSServer', 'QFTPServer', 'QHTTPProxyServer', 'QHTTPServer', 'QHTTPSServer', 'QIMAPServer', 'QMysqlServer', 'QPOP3Server', 'QPostgresServer', 'QRedisServer', 'QSMBServer', 'QSMTPServer', 'QSOCKS5Server', 'QSSHServer', 'QTelnetServer', 'QVNCServer', 'QElasticServer', 'QMSSQLServer', 'QLDAPServer', 'QNTPServer', 'QMemcacheServer', 'QOracleServer', 'QSNMPServer']
 temp_honeypots = []
 
 from signal import signal, alarm, SIGALRM, SIG_IGN, SIGTERM, SIGINT, SIGTSTP
@@ -76,7 +76,7 @@ def server_timeout(object, name):
 
 def main_logic():
 
-    from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPServer, QHTTPSServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, QMSSQLServer, QElasticServer, QLDAPServer, server_arguments, clean_all, postgres_class, setup_logger, QBSniffer, get_running_servers
+    from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPServer, QHTTPSServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, QMSSQLServer, QElasticServer, QLDAPServer, QNTPServer, QMemcacheServer, QOracleServer, QSNMPServer, server_arguments, clean_all, postgres_class, setup_logger, QBSniffer, get_running_servers
     from atexit import register
     from argparse import ArgumentParser, SUPPRESS
     from sys import stdout
@@ -97,11 +97,11 @@ def main_logic():
 
     ARG_PARSER = _ArgumentParser(description='Qeeqbox/honeypots customizable honeypots for monitoring network traffic, bots activities, and username\\password credentials', usage=SUPPRESS)
     ARG_PARSER._action_groups.pop()
-    ARG_PARSER_SETUP = ARG_PARSER.add_argument_group("Arguments")
+    ARG_PARSER_SETUP = ARG_PARSER.add_argument_group('Arguments')
     ARG_PARSER_SETUP.add_argument('--setup', help='target honeypot E.g. ssh or you can have multiple E.g ssh,http,https', metavar='', default='')
     ARG_PARSER_SETUP.add_argument('--list', action='store_true', help='list all available honeypots')
     ARG_PARSER_SETUP.add_argument('--kill', action='store_true', help='kill all honeypots')
-    ARG_PARSER_OPTIONAL = ARG_PARSER.add_argument_group("Optional")
+    ARG_PARSER_OPTIONAL = ARG_PARSER.add_argument_group('Optional')
     ARG_PARSER_OPTIONAL.add_argument('--termination-strategy', help='Determines the strategy to terminate by', default='input', choices=['input', 'signal'])
     ARG_PARSER_OPTIONAL.add_argument('--ip', help='Override the IP', metavar='', default='')
     ARG_PARSER_OPTIONAL.add_argument('--port', help='Override the Port (Do not use on multiple!)', metavar='', default='')
@@ -109,7 +109,7 @@ def main_logic():
     ARG_PARSER_OPTIONAL.add_argument('--password', help='Override the password', metavar='', default='')
     ARG_PARSER_OPTIONAL.add_argument('--config', help='Use a config file for honeypots settings', metavar='', default='')
     ARG_PARSER_OPTIONAL.add_argument('--test', action='store_true', help='Test a honeypot')
-    ARG_PARSER_CHAMELEON = ARG_PARSER.add_argument_group("Chameleon")
+    ARG_PARSER_CHAMELEON = ARG_PARSER.add_argument_group('Chameleon')
     ARG_PARSER_CHAMELEON.add_argument('--chameleon', action='store_true', help='reserved for chameleon project')
     ARG_PARSER_CHAMELEON.add_argument('--sniffer', action='store_true', help='sniffer - reserved for chameleon project')
     ARG_PARSER_CHAMELEON.add_argument('--iptables', action='store_true', help='iptables - reserved for chameleon project')
@@ -122,17 +122,17 @@ def main_logic():
             except BaseException:
                 print('[!] Unable to load or parse config.json file')
                 exit()
-            if "db" in config_data["logs"]:
+            if 'db' in config_data['logs']:
                 uuid = 'honeypotslogger' + '_' + 'main' + '_' + str(uuid4())[:8]
-                if "db_options" in config_data:
-                    if "drop" in config_data["db_options"]:
+                if 'db_options' in config_data:
+                    if 'drop' in config_data['db_options']:
                         print('[x] Setup Logger {} with a db, drop is on'.format(uuid))
                         logs = setup_logger(uuid, ARGV.config, True)
                     else:
                         print('[x] Setup Logger {} with a db, drop is off'.format(uuid))
                         logs = setup_logger(uuid, ARGV.config, False)
                 else:
-                    logs = setup_logger(uuid, ARGV.config, False)
+                    logs = setup_logger(uuid, ARGV.config, True)
     if ARGV.list:
         list_all_honeypots()
     elif ARGV.kill:
@@ -142,9 +142,9 @@ def main_logic():
         if config_data['filter'] and config_data['interface']:
             if not ARGV.test:
                 if ARGV.sniffer:
-                    current_interfaces = "unknown"
+                    current_interfaces = 'unknown'
                     try:
-                        current_interfaces = " ".join(interfaces())
+                        current_interfaces = ' '.join(interfaces())
                         if config_data['interface'] in current_interfaces:
                             print('[x] Your IP: {}'.format(ifaddresses(config_data['interface'])[AF_INET][0]['addr']))
                             print('[x] Your MAC: {}'.format(ifaddresses(config_data['interface'])[AF_LINK][0]['addr']))
@@ -163,7 +163,7 @@ def main_logic():
                     stdout.flush()
                     sleep(2)
 
-            if ARGV.config != "":
+            if ARGV.config != '':
                 print('[x] Config.json file overrides --ip, --port, --username and --password')
 
             if isinstance(config_data['honeypots'], dict):
@@ -171,7 +171,7 @@ def main_logic():
                 for honeypot in config_data['honeypots']:
                     for _honeypot in all_servers:
                         if 'q{}server'.format(honeypot).lower() == _honeypot.lower():
-                            if ARGV.port != "":
+                            if ARGV.port != '':
                                 ARGV.port = int(ARGV.port)
                             x = locals()[_honeypot](ip=ARGV.ip, port=ARGV.port, username=ARGV.username, password=ARGV.password, config=ARGV.config)
                             if not ARGV.test:
@@ -188,7 +188,7 @@ def main_logic():
                 for server in config_data['honeypots'].split(','):
                     for honeypot in all_servers:
                         if 'q{}server'.format(server).lower() == honeypot.lower():
-                            if ARGV.port != "":
+                            if ARGV.port != '':
                                 ARGV.port = int(ARGV.port)
                             x = locals()[honeypot](ip=ARGV.ip, port=ARGV.port, username=ARGV.username, password=ARGV.password, config=ARGV.config)
                             if not ARGV.test:
@@ -234,14 +234,18 @@ def main_logic():
         if ARGV.termination_strategy == 'input':
             print('[x] Use [Enter] to exit or python3 -m honeypots --kill')
 
-        if ARGV.config != "":
+        if ARGV.config != '':
             print('[x] config.json file overrides --ip, --port, --username and --password')
 
         if ARGV.setup == 'all':
-            for honeypot in all_servers:
-                x = locals()[honeypot](ip=ARGV.ip, username=ARGV.username, password=ARGV.password, config=ARGV.config)
-                x.run_server(process=True, auto=True)
-                temp_honeypots.append(x)
+            try:
+                for honeypot in all_servers:
+                    status = False
+                    x = locals()[honeypot](ip=ARGV.ip, username=ARGV.username, password=ARGV.password, config=ARGV.config)
+                    status = x.run_server(process=True, auto=True)
+                    temp_honeypots.append([x, status])
+            except Exception as e:
+                print(e)
         else:
             servers = ARGV.setup.split(',')
             for server in servers:
@@ -251,45 +255,58 @@ def main_logic():
                         if 'q{}server'.format(server.split(':')[0]).lower() == honeypot.lower():
                             ARGV.port = int(server.split(':')[1])
                             x = locals()[honeypot](ip=ARGV.ip, port=ARGV.port, username=ARGV.username, password=ARGV.password, config=ARGV.config)
+                            status = False
                             if not ARGV.test:
-                                x.run_server(process=True)
+                                status = x.run_server(process=True)
                             else:
                                 server_timeout(x, honeypot)
                                 x.kill_server()
-                            temp_honeypots.append(x)
-                elif ARGV.port != "":
+                            temp_honeypots.append([x, status])
+                elif ARGV.port != '':
                     for honeypot in all_servers:
                         if 'q{}server'.format(server).lower() == honeypot.lower():
                             x = locals()[honeypot](ip=ARGV.ip, port=int(ARGV.port), username=ARGV.username, password=ARGV.password, config=ARGV.config)
+                            status = False
                             if not ARGV.test:
-                                x.run_server(process=True)
+                                status = x.run_server(process=True)
                             else:
                                 server_timeout(x, honeypot)
                                 x.kill_server()
-                            temp_honeypots.append(x)
+                            temp_honeypots.append([x, status])
                 else:
                     for honeypot in all_servers:
                         if 'q{}server'.format(server).lower() == honeypot.lower():
                             x = locals()[honeypot](ip=ARGV.ip, username=ARGV.username, password=ARGV.password, config=ARGV.config)
+                            status = False
                             if not ARGV.test:
-                                x.run_server(process=True, auto=True)
+                                status = x.run_server(process=True, auto=True)
                             else:
                                 print('[x] {} was configured with random port, unable to test..'.format(honeypot))
-                            temp_honeypots.append(x)
+                            temp_honeypots.append([x, status])
 
         if len(temp_honeypots) > 0:
-            print('[x] Everything looks good!')
-            if not ARGV.test:
-                Termination(ARGV.termination_strategy).await_termination()
+            good = True
+            for server in temp_honeypots:
+                if server[1] == False or server[1] == None:
+                    good = False
+            if good:
+                print('[x] Everything looks good!')
+            else:
+                print('[x] Something is wrong!')
+
+            if good:
+                if not ARGV.test:
+                    Termination(ARGV.termination_strategy).await_termination()
 
             for server in temp_honeypots:
                 try:
                     if not ARGV.test:
-                        print('[x] Killing {} honeypot'.format(server.__class__.__name__))
+                        print('[x] Killing {} honeypot'.format(server[0].__class__.__name__))
                     else:
-                        print('[x] Killing {} tester'.format(server.__class__.__name__))
-                    server.kill_server()
-                except BaseException:
+                        print('[x] Killing {} tester'.format(server[0].__class__.__name__))
+                    server[0].kill_server()
+                except Exception as e:
+                    print(e)
                     pass
             print('[x] Please wait few seconds')
             sleep(5)
