@@ -14,9 +14,7 @@ from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
 
 from cgi import FieldStorage
-from requests import get, post
 from requests.packages.urllib3 import disable_warnings
-from time import sleep
 from twisted.internet import reactor
 from twisted.web.server import Site
 from twisted.web.resource import Resource
@@ -143,28 +141,31 @@ class QHTTPServer():
 
                     for item, value in dict(request.requestHeaders.getAllRawHeaders()).items():
                         headers.update({check_bytes(item): ','.join(map(check_bytes, value))})
+                    headers.update({'method': check_bytes(request.method)})
+                    headers.update({'uri': check_bytes(request.uri)})
                 except BaseException:
                     pass
 
-                _q_s.logs.info(['servers', {'server': 'http_server', 'action': 'connection', 'ip': request.getClientIP(), 'request': headers}])
+                _q_s.logs.info({'server': 'http_server', 'action': 'connection', 'src_ip': request.getHost().host, 'src_port': request.getHost().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'request': headers})
 
                 if self.server != '':
                     request.responseHeaders.removeHeader('Server')
                     request.responseHeaders.addRawHeader('Server', self.server)
 
+                if request.method == b'GET' or request.method == b'POST':
+                    _q_s.logs.info({'server': 'http_server', 'action': request.method.decode(), 'src_ip': request.getHost().host, 'src_port': request.getHost().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
+
                 if request.method == b'GET':
-                    _q_s.logs.info(['servers', {'server': 'http_server', 'action': 'get', 'ip': request.getClientIP()}])
                     if request.uri == b'/login.html':
                         if _q_s.username != '' and _q_s.password != '':
                             request.responseHeaders.addRawHeader('Content-Type', 'text/html; charset=utf-8')
                             return self.login_file
 
                     request.responseHeaders.addRawHeader('Content-Type', 'text/html; charset=utf-8')
-                    return self.home_file
+                    return self.login_file
 
                 elif request.method == b'POST':
                     self.headers = request.getAllHeaders()
-                    _q_s.logs.info(['servers', {'server': 'http_server', 'action': 'post', 'ip': request.getClientIP()}])
                     if request.uri == b'/login.html' or b'/':
                         if _q_s.username != '' and _q_s.password != '':
                             form = FieldStorage(fp=request.content, headers=self.headers, environ={'REQUEST_METHOD': 'POST', 'CONTENT_TYPE': self.headers[b'content-type'], })
@@ -176,7 +177,7 @@ class QHTTPServer():
                                     username = _q_s.username
                                     password = _q_s.password
                                     status = 'success'
-                                _q_s.logs.info(['servers', {'server': 'http_server', 'action': 'login', 'status': status, 'ip': request.getClientIP(), 'username': username, 'password': password}])
+                                _q_s.logs.info({'server': 'http_server', 'action': 'login', 'status': status, 'src_ip': request.getHost().host, 'src_port': request.getHost().port, 'username': username, 'password': password, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
                     request.responseHeaders.addRawHeader('Content-Type', 'text/html; charset=utf-8')
                     return self.home_file
@@ -204,7 +205,7 @@ class QHTTPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'http_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'http_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -214,9 +215,17 @@ class QHTTPServer():
         else:
             self.http_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('http_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('http_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
-            sleep(2)
+            from requests import get, post
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -226,14 +235,6 @@ class QHTTPServer():
         except BaseException:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('http_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('http_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
