@@ -16,16 +16,12 @@ filterwarnings(action='ignore', module='.*OpenSSL.*')
 from twisted.internet.protocol import Protocol, Factory
 from twisted.internet import reactor
 from twisted.python import log as tlog
-from hashlib import sha1
 from subprocess import Popen
 from os import path
-from struct import unpack, pack
-from binascii import unhexlify, hexlify
-from pymssql import connect as pconnect
+from struct import unpack
+from binascii import unhexlify
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
-from ldap3 import Server, Connection, ALL
-from time import sleep
 
 
 class QLDAPServer():
@@ -66,7 +62,7 @@ class QLDAPServer():
 
             def connectionMade(self):
                 self._state = 1
-                _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'ldap_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
             def parse_ldap_packet(self, data):
 
@@ -107,9 +103,9 @@ class QLDAPServer():
                     password = self.check_bytes(password)
                     if username != '' or password != '':
                         if username == _q_s.username and password == _q_s.password:
-                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
+                            _q_s.logs.info({'server': 'ldap_server', 'action': 'login', 'status': 'success', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': _q_s.username, 'password': _q_s.password})
                         else:
-                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                            _q_s.logs.info({'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
                     self.transport.write(unhexlify(b'300c02010165070a013204000400'))
                 elif self._state == 2:
                     self._state = 3
@@ -118,9 +114,9 @@ class QLDAPServer():
                     password = self.check_bytes(password)
                     if username != '' or password != '':
                         if username == _q_s.username and password == _q_s.password:
-                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
+                            _q_s.logs.info({'server': 'ldap_server', 'action': 'login', 'status': 'success', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': _q_s.username, 'password': _q_s.password})
                         else:
-                            _q_s.logs.info(['servers', {'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                            _q_s.logs.info({'server': 'ldap_server', 'action': 'login', 'status': 'failed', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
                     self.transport.write(unhexlify(b'300c02010265070a013204000400'))
                 else:
                     self.transport.loseConnection()
@@ -150,7 +146,7 @@ class QLDAPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'ldap_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'ldap_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -160,8 +156,17 @@ class QLDAPServer():
         else:
             self.ldap_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('ldap_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('ldap_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from ldap3 import Server, Connection, ALL
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -172,14 +177,6 @@ class QLDAPServer():
         except Exception as e:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('ldap_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('ldap_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
