@@ -17,12 +17,10 @@ from twisted.internet.protocol import Protocol, Factory
 from twisted.internet import reactor
 from twisted.python import log as tlog
 from struct import pack
-from hashlib import sha1
 from subprocess import Popen
 from os import path
 from struct import unpack, pack
 from binascii import unhexlify, hexlify
-from pymssql import connect as pconnect
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
 
@@ -86,7 +84,7 @@ class QMSSQLServer():
 
             def connectionMade(self):
                 self._state = 1
-                _q_s.logs.info(['servers', {'server': 'mssql_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'mssql_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
             def dataReceived(self, data):
                 if self._state == 1:
@@ -109,7 +107,7 @@ class QMSSQLServer():
                             username = _q_s.username
                             password = _q_s.password
                             status = 'success'
-                        _q_s.logs.info(['servers', {'server': 'mssql_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                        _q_s.logs.info({'server': 'mssql_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
 
                         self.transport.write(unhexlify(self.create_payload(token_error_msg=b'Login Failed', error_code=18456)))
                 else:
@@ -140,7 +138,7 @@ class QMSSQLServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'mssql_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'mssql_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -150,8 +148,17 @@ class QMSSQLServer():
         else:
             self.mssql_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('mssql_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('mssql_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from pymssql import connect as pconnect
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -161,14 +168,6 @@ class QMSSQLServer():
         except Exception as e:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('mssql_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('mssql_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
