@@ -15,15 +15,11 @@ filterwarnings(action='ignore', module='.*OpenSSL.*')
 
 from twisted.internet.protocol import Protocol, Factory
 from twisted.internet import reactor
-from redis import StrictRedis
 from twisted.python import log as tlog
 from subprocess import Popen
 from os import path
-from random import randint, uniform
-from time import time
 from struct import unpack
 from re import findall
-from socket import socket, AF_INET, SOCK_STREAM
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running, set_local_vars
 from uuid import uuid4
 
@@ -86,18 +82,18 @@ class QOracleServer():
                                         program = value.decode()
                                     elif name.startswith(b'USER'):
                                         local_user = value.decode()
-                except Exception as e:
+                except Exception:
                     pass
 
                 return service_name, program, local_user
 
             def connectionMade(self):
-                _q_s.logs.info(['servers', {'server': 'oracle_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'oracle_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
             def dataReceived(self, data):
                 service_name, program, local_user = self.parse_payload(data)
                 if service_name or program or local_user:
-                    _q_s.logs.info(['servers', {'server': 'oracle_server', 'action': 'login', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'local_user': local_user, 'program': program, 'service_name': service_name}])
+                    _q_s.logs.info({'server': 'oracle_server', 'action': 'login', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'local_user': local_user, 'program': program, 'service_name': service_name})
                 self.transport.write(self.refuse_payload())
                 self.transport.loseConnection()
 
@@ -123,7 +119,7 @@ class QOracleServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'oracle_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port}])
+            self.logs.info({'server': 'oracle_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port})
 
             if status == 'success':
                 return True
@@ -133,8 +129,17 @@ class QOracleServer():
         else:
             self.oracle_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('oracle_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('oracle_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from socket import socket, AF_INET, SOCK_STREAM
             payload = b'\x00\x00\x03\x04\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x08\x00E\x00\x01F\xb9\xd9@\x00@\x06\x81\xd6\x7f\x00\x00\x01\x7f\x00\x00\x01\xbf\xce\x06\x13\xacW\xde\xc0Z\xb5\x0cI\x80\x18\x02\x00\xff:\x00\x00\x01\x01\x08\n\x1bdZ^\x1bdZ^\x01\x12\x00\x00\x01\x00\x00\x00\x01>\x01,\x0cA \x00\xff\xff\x7f\x08\x00\x00\x01\x00\x00\xc8\x00J\x00\x00\x14\x00AA\xa7C\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00 \x00\x00 \x00\x00\x00\x00\x00\x00\x00\x00\x00\x01(DESCRIPTION=(CONNECT_DATA=(SERVICE_NAME=xe)(CID=(PROGRAM=linux_1)(HOST=xxxxxxxxxxxxxx)(USER=xxxxxxxxxxxxxx))(CONNECTION_ID=xxxxxxxxxxxxxxxxxxxxxxxx))(ADDRESS=(PROTOCOL=tcp)(HOST=xxxxxxx)(PORT=xxxx)))'
             _ip = ip or self.ip
             _port = port or self.port
@@ -145,14 +150,6 @@ class QOracleServer():
         except BaseException:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('oracle_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('oracle_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
