@@ -16,11 +16,9 @@ filterwarnings(action='ignore', category=DeprecationWarning)
 from smtpd import SMTPChannel, SMTPServer
 from asyncore import loop
 from base64 import b64decode
-from time import sleep
-from smtplib import SMTP
 from os import path
 from subprocess import Popen
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
+from honeypots.helper import check_if_server_is_running, close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, set_local_vars, setup_logger
 from uuid import uuid4
 
 
@@ -58,7 +56,7 @@ class QSMTPServer():
                     return str(string)
 
             def smtp_EHLO(self, arg):
-                _q_s.logs.info(['servers', {'server': 'smtp_server', 'action': 'connection', 'ip': self.addr[0], 'port':self.addr[1]}])
+                _q_s.logs.info({'server': 'smtp_server', 'action': 'connection', 'src_ip': self.addr[0], 'src_port': self.addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
                 if not arg:
                     self.push('501 Syntax: HELO hostname')
                 if self._SMTPChannel__greeting:
@@ -81,11 +79,10 @@ class QSMTPServer():
                             username = _q_s.username
                             password = _q_s.password
                             status = 'success'
-                        _q_s.logs.info(['servers', {'server': 'smtp_server', 'action': 'login', 'status': status, 'ip': self.addr[0], 'port':self.addr[1], 'username':username, 'password':password}])
+                        _q_s.logs.info({'server': 'smtp_server', 'action': 'login', 'status': status, 'src_ip': self.addr[0], 'src_port': self.addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
 
                 except Exception as e:
-                    print(e)
-                    _q_s.logs.error(['errors', {'server': 'smtp_server', 'error': 'smtp_AUTH', 'type': 'error -> ' + repr(e)}])
+                    pass
 
                 self.push('235 Authentication successful')
 
@@ -123,7 +120,7 @@ class QSMTPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'smtp_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'smtp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -133,9 +130,17 @@ class QSMTPServer():
         else:
             self.smtp_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('smtp_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('smtp_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
-            sleep(2)
+            from smtplib import SMTP
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -148,14 +153,6 @@ class QSMTPServer():
         except BaseException:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('smtp_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('smtp_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
