@@ -13,16 +13,14 @@
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*paramiko.*')
 
-from paramiko import ServerInterface, Transport, RSAKey, AutoAddPolicy
+from paramiko import RSAKey, ServerInterface, Transport
 from socket import socket, AF_INET, SOCK_STREAM, SOL_SOCKET, SO_REUSEADDR
 from _thread import start_new_thread
 from io import StringIO
 from random import choice
-from time import sleep
-from paramiko import SSHClient
 from subprocess import Popen
 from os import path
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
+from honeypots.helper import check_if_server_is_running, close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, set_local_vars, setup_logger
 from uuid import uuid4
 
 
@@ -82,13 +80,13 @@ class QSSHServer():
                     username = _q_s.username
                     password = _q_s.password
                     status = 'success'
-                _q_s.logs.info(['servers', {'server': 'ssh_server', 'action': 'login', 'status': status, 'ip': self.ip, 'port': self.port, 'username': username, 'password': password}])
+                _q_s.logs.info({'server': 'ssh_server', 'action': 'login', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
 
         def ConnectionHandle(client, priv):
             try:
                 t = Transport(client)
                 ip, port = client.getpeername()
-                _q_s.logs.info(['servers', {'server': 'ssh_server', 'action': 'connection', 'ip': ip, 'port': port}])
+                _q_s.logs.info({'server': 'ssh_server', 'action': 'connection', 'src_ip': ip, 'src_port': port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
                 t.local_version = 'SSH-2.0-' + choice(self.random_servers)
                 t.add_server_key(RSAKey(file_obj=StringIO(priv)))
                 t.start_server(server=SSHHandle(ip, port))
@@ -127,7 +125,7 @@ class QSSHServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'ssh_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'ssh_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -137,19 +135,6 @@ class QSSHServer():
         else:
             self.ssh_server_main()
 
-    def test_server(self, ip=None, port=None, username=None, password=None):
-        try:
-            sleep(2)
-            _ip = ip or self.ip
-            _port = port or self.port
-            _username = username or self.username
-            _password = password or self.password
-            ssh = SSHClient()
-            ssh.set_missing_host_key_policy(AutoAddPolicy())  # if you have default ones, remove them before using this..
-            ssh.connect(_ip, port=_port, username=_username, password=_password)
-        except BaseException:
-            pass
-
     def close_port(self):
         ret = close_port_wrapper('ssh_server', self.ip, self.port, self.logs)
         return ret
@@ -158,6 +143,20 @@ class QSSHServer():
         ret = kill_server_wrapper('ssh_server', self.uuid, self.process)
         return ret
 
+    def test_server(self, ip=None, port=None, username=None, password=None):
+        try:
+            from paramiko import SSHClient, AutoAddPolicy
+            _ip = ip or self.ip
+            _port = port or self.port
+            _username = username or self.username
+            _password = password or self.password
+            ssh = SSHClient()
+            ssh.set_missing_host_key_policy(AutoAddPolicy())  # if you have default ones, remove them before using this..
+            ssh.connect(_ip, port=_port, username=_username, password=_password)
+        except Exception as e:
+            print(e)
+            pass
+
 
 if __name__ == '__main__':
     parsed = server_arguments()
