@@ -16,7 +16,6 @@ filterwarnings(action='ignore', module='.*OpenSSL.*')
 from twisted.conch.telnet import TelnetProtocol, TelnetTransport
 from twisted.internet.protocol import Factory
 from twisted.internet import reactor
-from telnetlib import Telnet as TTelnet
 from twisted.python import log as tlog
 from subprocess import Popen
 from os import path
@@ -67,7 +66,7 @@ class QTelnetServer():
                 self._pass = None
                 self.transport.write(b'PC login: ')
                 self._state = b'Username'
-                _q_s.logs.info(['servers', {'server': 'telnet_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'telnet_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
             def dataReceived(self, data):
                 data = data.strip()
@@ -84,7 +83,7 @@ class QTelnetServer():
                         username = _q_s.username
                         password = _q_s.password
                         status = 'success'
-                    _q_s.logs.info(['servers', {'server': 'telnet_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                    _q_s.logs.info({'server': 'telnet_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
                     self.transport.loseConnection()
                 else:
                     self.transport.loseConnection()
@@ -116,7 +115,7 @@ class QTelnetServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'telnet_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'telnet_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -126,8 +125,17 @@ class QTelnetServer():
         else:
             self.telent_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('telnet_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('telnet_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from telnetlib import Telnet as TTelnet
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -143,14 +151,6 @@ class QTelnetServer():
             print(e)
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('telnet_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('telnet_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
